@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 """
+hio.hioing module
+
 Generic Constants and Classes
+Exception Classes
+
 """
 import sys
 from collections import namedtuple
@@ -20,6 +24,7 @@ class HioError(Exception):
     To use   raise HioError("Error: message")
     """
 
+
 class ValidationError(HioError):
     """
     Validation related errors
@@ -27,6 +32,7 @@ class ValidationError(HioError):
         raise ValidationError("error message")
     """
 
+
 class VersionError(ValidationError):
     """
     Bad or Unsupported Version
@@ -37,3 +43,11 @@ class VersionError(ValidationError):
 
 
 
+class MixIn(object):
+    """
+    Base class to enable consistent MRO for mixin multiple inheritance
+    Allows each subclass to call super(SubClass,self).__init__(**kwa)
+    So propagates to common top of Tree
+    """
+    def __init__(self, *pa, **kwa):
+        pass
